@@ -1,9 +1,9 @@
 package Test::NaiveStubs;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Generate test stubs for methods
+# ABSTRACT: Generate test stubs for methods and functions
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -12,7 +12,7 @@ use namespace::clean;
 use Class::Sniff;
 
 
-has class => (
+has module => (
     is       => 'ro',
     required => 1,
 );
@@ -25,7 +25,7 @@ has name => (
 
 sub _build_name {
     my ($self) = @_;
-    ( my $name = $self->class ) =~ s/::/-/g;
+    ( my $name = $self->module ) =~ s/::/-/g;
     $name = lc $name;
     return "$name.t";
 }
@@ -34,7 +34,7 @@ sub _build_name {
 sub gather_methods {
     my ($self) = @_;
 
-    my $sniff = Class::Sniff->new({ class => $self->class });
+    my $sniff = Class::Sniff->new({ class => $self->module });
     my @methods = $sniff->methods;
     my %methods;
     @methods{@methods} = undef;
@@ -49,11 +49,11 @@ sub unit_test {
     my $test = '';
 
     if ( $subroutine eq 'new' ) {
-        $test = 'use_ok "' . $self->class . '";'
+        $test = 'use_ok "' . $self->module . '";'
             . "\n\n"
-            . 'my $obj = ' . $self->class . '->new;'
+            . 'my $obj = ' . $self->module . '->new;'
             . "\n"
-            . 'isa_ok $obj, "' . $self->class . '";';
+            . 'isa_ok $obj, "' . $self->module . '";';
     }
     else {
         $test = 'ok $obj->can("' . $subroutine . '"), "' . $subroutine . '";';
@@ -106,46 +106,46 @@ __END__
 
 =head1 NAME
 
-Test::NaiveStubs - Generate test stubs for methods
+Test::NaiveStubs - Generate test stubs for methods and functions
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
   use Test::NaiveStubs;
   my $tns = Test::NaiveStubs->new(
-    class => 'Foo::Bar',
-    name  => 't/foo-bar.t',
+    module => 'Foo::Bar',
+    name   => 't/foo-bar.t',
   );
   $tns->create_test;
 
 =head1 DESCRIPTION
 
-C<Test::NaiveStubs> generates a test file of stubs for exercising all the
-methods (not functions) of a given B<class>.
+C<Test::NaiveStubs> generates a test file of stubs exercising all the methods or
+functions of a given module (the B<module> attribute).
 
 Unfortunately L<Class::Sniff> returns I<imported> methods as well as the ones in
-the B<class> you have given.  So you will have to remove those lines from the
+the B<module> you have given.  So you will have to remove those lines from the
 generated test file by hand.
 
 For a more powerful alternative, check out L<Test::StubGenerator>.
 
 =head1 ATTRIBUTES
 
-=head2 class
+=head2 module
 
-  $class = $tns->class;
+  $module = $tns->module;
 
-The class name to use in the test generation.
+The module name to use in the test generation.
 
 =head2 name
 
   $name = $tns->name;
 
 The test output file name.  If not given in the constructor, the filename is
-created from the B<class>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
+created from the B<module>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
 
 =head1 METHODS
 
@@ -159,7 +159,7 @@ Create a new C<Test::NaiveStubs> object.
 
   $methods = $tns->gather_methods;
 
-Return the methods of the given B<class>, as well as imported methods, as a hash
+Return the methods of the given B<module>, as well as imported methods, as a hash
  reference.
 
 =head2 unit_test()
